==> haskell-success-0.2.6-302-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 success
version:              0.2.6
visibility:           public
id:                   success-0.2.6-KD9nZomN0638vwNwV12ZOe
key:                  success-0.2.6-KD9nZomN0638vwNwV12ZOe
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/success 
synopsis:
    A version of Either specialised for encoding of success or failure

description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.

category:             Data, Failure
abi:                  898e188211666cbeaf05d7552bd3c9d9
exposed:              True
exposed-modules:      Success.Impure Success.Pure
import-dirs:          /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-success
hs-libraries:         HSsuccess-0.2.6-KD9nZomN0638vwNwV12ZOe
depends:
    base-4.17.2.1 monad-control-1.0.3.1-2MwvUvBtsCMC9JvU7HfDDX
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-3xf5KPJy0SA2JWTsENPu37

haddock-interfaces:   /usr/share/doc/haskell-success/html/success.haddock
haddock-html:         /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-303-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 success
version:              0.2.6
visibility:           public
id:                   success-0.2.6-8ZjqEh3vWpiIKuIFj3ULbd
key:                  success-0.2.6-8ZjqEh3vWpiIKuIFj3ULbd
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/success 
synopsis:
    A version of Either specialised for encoding of success or failure

description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.

category:             Data, Failure
abi:                  1e134b3edf56ba5463e03e88a58d2aaf
exposed:              True
exposed-modules:      Success.Impure Success.Pure
import-dirs:          /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-success
hs-libraries:         HSsuccess-0.2.6-8ZjqEh3vWpiIKuIFj3ULbd
depends:
    base-4.17.2.1 monad-control-1.0.3.1-Bm33cSyu4Uq1sNtabsMyLN
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-FFK8b18n3VCIGQX7cmARkw

haddock-interfaces:   /usr/share/doc/haskell-success/html/success.haddock
haddock-html:         /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
